( cd usr/share/doc/HTML/en/katapult ; rm -rf common )
( cd usr/share/doc/HTML/en/katapult ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/lib ; rm -rf libkatapult.so.2 )
( cd usr/lib ; ln -sf libkatapult.so.2.0.0 libkatapult.so.2 )
( cd usr/lib ; rm -rf libkatapult.so )
( cd usr/lib ; ln -sf libkatapult.so.2.0.0 libkatapult.so )
